# outer __init__.py

from .pandas.drop import drop
from .pandas.makes_up import makes_up
from .pandas.resemble import resemble
from .pandas.distort import distort
from .pandas.subset_by_levels import subset_by_levels
from .pandas.polynomializer import polynomializer

from .groups.fold import fold
from .groups.group_uniques import group_uniques
from .groups.group import group
from .groups.partition import partition

from .array.blend import blend
from .array.windowed_reverse import windowed_reverse



#!/usr/bin/env
# -*- coding: utf-8 -*-
"""
@author: ludvigolsen
"""

from setuptools import setup

setup(name='utipy',
      version='0.2.3',
      description='Utility functions for python',
      long_description='Pandas and array operations. Data grouping, folding, and partitioning.',
      classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Utilities',
      ],
      keywords='pandas numpy array ndarray groups folds kfold partitioning utilities tools',
      url='http://github.com/ludvigolsen/utipy',
      author='Ludvig Renbo Olsen',
      author_email='mail@ludvigolsen.dk',
      license='MIT',
      packages=['utipy'],
      install_requires=[
          'pandas',
          'numpy'
      ],
      include_package_data=True,
      zip_safe=False)